[postgis-tickets] [SCM] PostGIS; Spatial objects for PostgreSQL. branch master updated. 4ae90beb56b677a8497ea2cdc26d1226933c8e4d

git at osgeo.org git at osgeo.org
Tue Oct 29 01:11:29 PDT 2019


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "PostGIS; Spatial objects for PostgreSQL.".

The branch, master has been updated
       via  4ae90beb56b677a8497ea2cdc26d1226933c8e4d (commit)
      from  6d0b491212882cbc8bc968b1a0e2bcec9d186ae7 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 4ae90beb56b677a8497ea2cdc26d1226933c8e4d
Author: Sandro Santilli <strk at kbt.io>
Date:   Tue Oct 29 09:07:13 2019 +0100

    Drop "svn" from revision header and generating script
    
    NOTE: we still have postgis_svn_version() function to deal with

diff --git a/.gitignore b/.gitignore
index 6a4e8d7..5213c3b 100644
--- a/.gitignore
+++ b/.gitignore
@@ -11,7 +11,7 @@
 *.gcda
 *.gcno
 gmon.out
-postgis_svn_revision.h
+postgis_revision.h
 aclocal.m4
 autom4te.cache/
 build-aux/
diff --git a/GNUmakefile.in b/GNUmakefile.in
index 4eb21d4..96d3097 100644
--- a/GNUmakefile.in
+++ b/GNUmakefile.in
@@ -25,7 +25,7 @@ all install uninstall noop clean distclean check-unit check-regress:
 		echo "PostGIS was built successfully. Ready to install."; \
 	fi
 
-all: postgis_svn_revision.h
+all: postgis_revision.h
 
 ifeq (@LIBLWGEOM_ONLY@,no)
 install: all comments-install
@@ -175,7 +175,7 @@ authors.git: authors.svn
 svnrebase: authors.git
 	git svn rebase --authors-file authors.git
 
-postgis_svn_revision.h:
-	$(PERL) utils/svn_repo_revision.pl
+postgis_revision.h:
+	$(PERL) utils/repo_revision.pl
 
-.PHONY: utils liblwgeom ChangeLog raster postgis_svn_revision.h
+.PHONY: utils liblwgeom ChangeLog raster postgis_revision.h
diff --git a/ci/debbie/postgis_release_docs.sh b/ci/debbie/postgis_release_docs.sh
index e0107e1..8398b08 100644
--- a/ci/debbie/postgis_release_docs.sh
+++ b/ci/debbie/postgis_release_docs.sh
@@ -38,12 +38,12 @@ LDFLAGS="-L${PGPATH}/lib"  ./configure \
   --without-raster --without-wagyu
 make clean
 
-# generating postgis_svn_revision.h in case hasn't been generated
-if test -f utils/svn_repo_revision.pl; then
-	echo "Generating postgis_svn_revision.h"
-	perl utils/svn_repo_revision.pl
+# generating postgis_revision.h in case hasn't been generated
+if test -f utils/repo_revision.pl; then
+	echo "Generating postgis_revision.h"
+	perl utils/repo_revision.pl
 fi
-export VREV="`cat postgis_svn_revision.h | awk '{print $3}'`"
+export VREV="`cat postgis_revision.h | awk '{print $3}'`"
 echo "SVN is ${VREV}"
 cd doc
 
diff --git a/liblwgeom/Makefile.in b/liblwgeom/Makefile.in
index b306621..5fe4cb2 100644
--- a/liblwgeom/Makefile.in
+++ b/liblwgeom/Makefile.in
@@ -167,11 +167,11 @@ install:
 
 uninstall:
 
-# Make all objects depend upon postgis_config.h and postgis_svn_revision.h
-$(LT_OBJS): ../postgis_config.h ../postgis_svn_revision.h $(SA_HEADERS)
+# Make all objects depend upon postgis_config.h and postgis_revision.h
+$(LT_OBJS): ../postgis_config.h ../postgis_revision.h $(SA_HEADERS)
 
-../postgis_svn_revision.h:
-	$(MAKE) -C .. postgis_svn_revision.h
+../postgis_revision.h:
+	$(MAKE) -C .. postgis_revision.h
 
 liblwgeom.la: $(LT_OBJS)
 	$(LIBTOOL) --tag=CC --mode=link $(CC) -rpath $(libdir) $(LT_OBJS) \
diff --git a/liblwgeom/lwgeom_api.c b/liblwgeom/lwgeom_api.c
index 90e7a99..161060e 100644
--- a/liblwgeom/lwgeom_api.c
+++ b/liblwgeom/lwgeom_api.c
@@ -30,7 +30,7 @@
 
 #include <stdio.h>
 #include <assert.h>
-#include "../postgis_svn_revision.h"
+#include "../postgis_revision.h"
 
 const char *
 lwgeom_version()
diff --git a/postgis/Makefile.in b/postgis/Makefile.in
index 76a2c01..5293e0c 100644
--- a/postgis/Makefile.in
+++ b/postgis/Makefile.in
@@ -194,12 +194,12 @@ endif
 # change is made, a PostGIS rebuild is triggered.
 #
 # Also they are all dependent on postgis_config.h
-# and thus postgis_svn_revision.h
+# and thus postgis_revision.h
 #
-$(PG_OBJS): ../liblwgeom/.libs/liblwgeom.a ../libpgcommon/libpgcommon.a ../postgis_config.h ../postgis_svn_revision.h $(WAGYU_DEP)
+$(PG_OBJS): ../liblwgeom/.libs/liblwgeom.a ../libpgcommon/libpgcommon.a ../postgis_config.h ../postgis_revision.h $(WAGYU_DEP)
 
-../postgis_svn_revision.h:
-	$(MAKE) -C .. postgis_svn_revision.h
+../postgis_revision.h:
+	$(MAKE) -C .. postgis_revision.h
 
 ../liblwgeom/.libs/liblwgeom.a:
 	$(MAKE) -C ../liblwgeom liblwgeom.la
@@ -256,7 +256,7 @@ sfcgal_upgrade.sql: sfcgal_upgrade.sql.in postgis_after_upgrade.sql
 	cat $^ > $@
 
 # SQL objects are also dependent on postgis_config.h for PostgreSQL version
-$(SQL_OBJS): ../postgis_config.h ../postgis_svn_revision.h
+$(SQL_OBJS): ../postgis_config.h ../postgis_revision.h
 
 #postgis.sql.in: sqldefines.h long_xact.sql.in.c geography.sql.in.c
 
diff --git a/postgis/sqldefines.h.in b/postgis/sqldefines.h.in
index 3a474a0..058b2b1 100644
--- a/postgis/sqldefines.h.in
+++ b/postgis/sqldefines.h.in
@@ -1,7 +1,7 @@
 #ifndef _LWPGIS_DEFINES
 #define _LWPGIS_DEFINES
 
-#include "../postgis_svn_revision.h"
+#include "../postgis_revision.h"
 
 /*
  * Define just the version numbers; otherwise we get some strange substitutions in postgis.sql.in
diff --git a/postgis_config.h.in b/postgis_config.h.in
index abb6f3f..9046281 100644
--- a/postgis_config.h.in
+++ b/postgis_config.h.in
@@ -1,7 +1,7 @@
 #ifndef POSTGIS_CONFIG_H
 #define POSTGIS_CONFIG_H 1
 
-#include "postgis_svn_revision.h"
+#include "postgis_revision.h"
 
 /* Manually manipulate the POSTGIS_DEBUG_LEVEL, it is not affected by the
    configure process */
diff --git a/raster/rt_pg/Makefile.in b/raster/rt_pg/Makefile.in
index 046fbb5..ef83534 100644
--- a/raster/rt_pg/Makefile.in
+++ b/raster/rt_pg/Makefile.in
@@ -128,10 +128,10 @@ endif
 # Objects dependencies
 # NOTE: the .a deps are really only link-time dependencies, but at this
 #       time I dunno how to wncode those
-$(OBJS): ../../liblwgeom/.libs/liblwgeom.a ../rt_core/librtcore.a ../../libpgcommon/libpgcommon.a ../../postgis_config.h ../../postgis_svn_revision.h
+$(OBJS): ../../liblwgeom/.libs/liblwgeom.a ../rt_core/librtcore.a ../../libpgcommon/libpgcommon.a ../../postgis_config.h ../../postgis_revision.h
 
 # SQL objects deps here
-$(SQL_OBJS): ../../postgis/sqldefines.h ../../postgis_svn_revision.h
+$(SQL_OBJS): ../../postgis/sqldefines.h ../../postgis_revision.h
 
 #this is redundant but trying to fold in with the  other just hangs
 rtpostgis_upgrade.sql.in: rtpostgis.sql ../../utils/postgis_proc_upgrade.pl
diff --git a/topology/Makefile.in b/topology/Makefile.in
index 7660b7a..e86fcf1 100644
--- a/topology/Makefile.in
+++ b/topology/Makefile.in
@@ -130,7 +130,7 @@ topology.sql: \
 	sql/topogeometry/simplify.sql.in \
 	sql/predicates.sql.in \
 	../postgis/sqldefines.h \
-	../postgis_svn_revision.h
+	../postgis_revision.h
 
 uninstall_topology.sql: topology.sql ../utils/create_undef.pl
 	$(PERL) ../utils/create_undef.pl $< $(POSTGIS_PGSQL_VERSION) > $@
diff --git a/utils/Makefile.in b/utils/Makefile.in
index 8a7e94e..8b22ff1 100644
--- a/utils/Makefile.in
+++ b/utils/Makefile.in
@@ -32,7 +32,7 @@ SCRIPTS_built = postgis_restore.pl
 
 SCRIPTS = \
 	create_undef.pl \
-	svn_repo_revision.pl \
+	repo_revision.pl \
 	postgis_proc_upgrade.pl \
 	profile_intersects.pl \
 	test_estimation.pl \
diff --git a/utils/svn_repo_revision.pl b/utils/repo_revision.pl
similarity index 98%
rename from utils/svn_repo_revision.pl
rename to utils/repo_revision.pl
index ed20f48..bc092a7 100755
--- a/utils/svn_repo_revision.pl
+++ b/utils/repo_revision.pl
@@ -6,7 +6,7 @@ use warnings;
 use strict;
 
 my $top_srcdir = ".";
-my $rev_file = $top_srcdir.'/postgis_svn_revision.h';
+my $rev_file = $top_srcdir.'/postgis_revision.h';
 
 my $target = 'local';
 $target = $ARGV[0] if $ARGV[0];

-----------------------------------------------------------------------

Summary of changes:
 .gitignore                                       |  2 +-
 GNUmakefile.in                                   |  8 ++++----
 ci/debbie/postgis_release_docs.sh                | 10 +++++-----
 liblwgeom/Makefile.in                            |  8 ++++----
 liblwgeom/lwgeom_api.c                           |  2 +-
 make_dist.sh                                     | 10 +++++-----
 postgis/Makefile.in                              | 10 +++++-----
 postgis/sqldefines.h.in                          |  2 +-
 postgis_config.h.in                              |  2 +-
 raster/rt_pg/Makefile.in                         |  4 ++--
 topology/Makefile.in                             |  2 +-
 utils/Makefile.in                                |  2 +-
 utils/{svn_repo_revision.pl => repo_revision.pl} |  2 +-
 13 files changed, 32 insertions(+), 32 deletions(-)
 rename utils/{svn_repo_revision.pl => repo_revision.pl} (98%)


hooks/post-receive
diff --git a/make_dist.sh b/make_dist.sh
index 91f1ccb..d0d62f2 100755
--- a/make_dist.sh
+++ b/make_dist.sh
@@ -92,10 +92,10 @@ owd="$PWD"
 cd "$outdir"
 ./autogen.sh
 ./configure ${CONFIGURE_ARGS}
-# generating postgis_svn_revision.h for >= 2.0.0 tags
-if test -f utils/svn_repo_revision.pl; then
-	echo "Generating postgis_svn_revision.h"
-	perl utils/svn_repo_revision.pl $svnurl
+# generating postgis_revision.h for >= 2.0.0 tags
+if test -f utils/repo_revision.pl; then
+	echo "Generating postgis_revision.h"
+	perl utils/repo_revision.pl $svnurl
 fi
 #make
 cd "$owd"
@@ -129,7 +129,7 @@ if test "$version" = "dev"; then
   VMAJ=`grep ^POSTGIS_MAJOR_VERSION "$outdir"/Version.config | cut -d= -f2`
   VMIN=`grep ^POSTGIS_MINOR_VERSION "$outdir"/Version.config | cut -d= -f2`
   VMIC=`grep ^POSTGIS_MICRO_VERSION "$outdir"/Version.config | cut -d= -f2`
-  VREV=`cat "$outdir"/postgis_svn_revision.h | awk '{print $3}'`
+  VREV=`cat "$outdir"/postgis_revision.h | awk '{print $3}'`
   version="${VMAJ}.${VMIN}.${VMIC}-r${VREV}"
   #if newoutdir is not already set, then set it
   if test "x$newoutdir" = "x"; then
-- 
PostGIS; Spatial objects for PostgreSQL.


More information about the postgis-tickets mailing list